Color class

An RGB color.

Implementers

Constructors

Color.rgb(int red, int green, int blue)
An RGB color.
const

Properties

blue → int
Blue color value for this color.
final
green → int
Green color value for this color.
final
hashCode → int
The hash code for this object.
no setterinherited
hex → String
The hex value calculated from red, blue, green.
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
red → int
Red color value for this color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited