ConfigColor class

A Color that is adapted from a configuration.

Inheritance

Constructors

ConfigColor({required int red, required int green, required int blue, required String name})
A Color that is adapted from a configuration.
const
ConfigColor.fromHex({required String hex, required String name})
A Color created from a hexadecimal value. Accepted formats include:
factory

Properties

blue → int
Blue color value for this color.
finalinherited
green → int
Green color value for this color.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hex → String
The hex value calculated from red, blue, green.
no setterinherited
name → String
The name of this color.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
red → int
Red color value for this color.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInt(String hex) → int
Convert the hex string into a base-10 integer.